@@ -7,13 +7,15 @@ from django.db import models, migrations
 class Migration(migrations.Migration):
 
     dependencies = [
-        ('twitter', '0012_auto_20150814_1730'),
+        ("twitter", "0012_auto_20150814_1730"),
     ]
 
     operations = [
         migrations.AddField(
-            model_name='user',
-            name='favorites',
-            field=models.ManyToManyField(related_name='favoriting_users', to='twitter.Tweet'),
+            model_name="user",
+            name="favorites",
+            field=models.ManyToManyField(
+                related_name="favoriting_users", to="twitter.Tweet"
+            ),
         ),
     ]
